summaryrefslogtreecommitdiffstats
path: root/tdescreensaver/kdesavers/rotation.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tdescreensaver/kdesavers/rotation.cpp')
-rw-r--r--tdescreensaver/kdesavers/rotation.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdescreensaver/kdesavers/rotation.cpp b/tdescreensaver/kdesavers/rotation.cpp
index c960c66c..9d9a1442 100644
--- a/tdescreensaver/kdesavers/rotation.cpp
+++ b/tdescreensaver/kdesavers/rotation.cpp
@@ -1,6 +1,6 @@
//============================================================================
//
// KRotation screen saver for KDE
//
// The screen saver displays a physically realistic simulation of a force free
// rotating asymmetric body. The equations of motion for such a rotation, the
@@ -36,7 +36,7 @@
#include <tqlineedit.h>
#include <tqvalidator.h>
#include <tqtooltip.h>
-// KDE headers
+// TDE headers
#include <tdelocale.h>
#include <tdeconfig.h>
#include <kdebug.h>
@@ -780,7 +780,7 @@ void KRotationSetup::okButtonClickedSlot(void)
void KRotationSetup::aboutButtonClickedSlot(void)
{
KMessageBox::about(this, i18n("\
-<h3>KRotation Screen Saver for KDE</h3>\
+<h3>KRotation Screen Saver for TDE</h3>\
<p>Simulation of a force free rotating asymmetric body</p>\
<p>Copyright (c) Georg&nbsp;Drenkhahn 2004</p>\
<p><tt>georg-d@users.sourceforge.net</tt></p>"));
@@ -1,6 +1,6 @@
//============================================================================
//
-// KRotation screen saver for KDE
+// KRotation screen saver for TDE
//
// The screen saver displays a physically realistic simulation of a force free